#' @keywords internal
"_PACKAGE"

# Suppress R CMD check note
# Namespace in Imports field not imported from: PKG
#   All declared Imports should be used.
# nocov start
ignore_unused_imports <- function() {
  econdatasets::ed_get()
  econid::add_entity_pattern()
  econtools::add_gdp_column()
  imfapi::imf_get()
  imfweo::weo_cache_reset()
  oecdoda::oda_get_crs()
  owidapi::owid_embed()
  uisapi::uis_bulk_files()
  wbids::ids_bulk()
  wbwdi::wdi_get()
}
# nocov end
